@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,14 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.data_fusion_v1.services.data_fusion import pagers
-from google.cloud.data_fusion_v1.types import datafusion
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DataFusionTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import DataFusionGrpcAsyncIOTransport
+
+from google.cloud.data_fusion_v1.services.data_fusion import pagers
+from google.cloud.data_fusion_v1.types import datafusion
+
 from .client import DataFusionClient
+from .transports.base import DEFAULT_CLIENT_INFO, DataFusionTransport
+from .transports.grpc_asyncio import DataFusionGrpcAsyncIOTransport
 
 
 class DataFusionAsyncClient:
@@ -218,14 +220,13 @@ class DataFusionAsyncClient:
         r"""Lists possible versions for Data Fusion instances in
         the specified project and location.
 
-
         .. code-block:: python
 
             from google.cloud import data_fusion_v1
 
-            def sample_list_available_versions():
+            async def sample_list_available_versions():
                 # Create a client
-                client = data_fusion_v1.DataFusionClient()
+                client = data_fusion_v1.DataFusionAsyncClient()
 
                 # Initialize request argument(s)
                 request = data_fusion_v1.ListAvailableVersionsRequest(
@@ -236,7 +237,7 @@ class DataFusionAsyncClient:
                 page_result = client.list_available_versions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -299,12 +300,20 @@ class DataFusionAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListAvailableVersionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -321,14 +330,13 @@ class DataFusionAsyncClient:
         r"""Lists Data Fusion instances in the specified project
         and location.
 
-
         .. code-block:: python
 
             from google.cloud import data_fusion_v1
 
-            def sample_list_instances():
+            async def sample_list_instances():
                 # Create a client
-                client = data_fusion_v1.DataFusionClient()
+                client = data_fusion_v1.DataFusionAsyncClient()
 
                 # Initialize request argument(s)
                 request = data_fusion_v1.ListInstancesRequest(
@@ -339,7 +347,7 @@ class DataFusionAsyncClient:
                 page_result = client.list_instances(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -379,12 +387,20 @@ class DataFusionAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListInstancesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -404,9 +420,9 @@ class DataFusionAsyncClient:
 
             from google.cloud import data_fusion_v1
 
-            def sample_get_instance():
+            async def sample_get_instance():
                 # Create a client
-                client = data_fusion_v1.DataFusionClient()
+                client = data_fusion_v1.DataFusionAsyncClient()
 
                 # Initialize request argument(s)
                 request = data_fusion_v1.GetInstanceRequest(
@@ -414,7 +430,7 @@ class DataFusionAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_instance(request=request)
+                response = await client.get_instance(request=request)
 
                 # Handle the response
                 print(response)
@@ -451,7 +467,12 @@ class DataFusionAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -470,14 +491,13 @@ class DataFusionAsyncClient:
         r"""Creates a new Data Fusion instance in the specified
         project and location.
 
-
         .. code-block:: python
 
             from google.cloud import data_fusion_v1
 
-            def sample_create_instance():
+            async def sample_create_instance():
                 # Create a client
-                client = data_fusion_v1.DataFusionClient()
+                client = data_fusion_v1.DataFusionAsyncClient()
 
                 # Initialize request argument(s)
                 request = data_fusion_v1.CreateInstanceRequest(
@@ -490,7 +510,7 @@ class DataFusionAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -570,7 +590,12 @@ class DataFusionAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -598,9 +623,9 @@ class DataFusionAsyncClient:
 
             from google.cloud import data_fusion_v1
 
-            def sample_delete_instance():
+            async def sample_delete_instance():
                 # Create a client
-                client = data_fusion_v1.DataFusionClient()
+                client = data_fusion_v1.DataFusionAsyncClient()
 
                 # Initialize request argument(s)
                 request = data_fusion_v1.DeleteInstanceRequest(
@@ -612,7 +637,7 @@ class DataFusionAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -650,9 +675,6 @@ class DataFusionAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -686,7 +708,12 @@ class DataFusionAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -715,9 +742,9 @@ class DataFusionAsyncClient:
 
             from google.cloud import data_fusion_v1
 
-            def sample_update_instance():
+            async def sample_update_instance():
                 # Create a client
-                client = data_fusion_v1.DataFusionClient()
+                client = data_fusion_v1.DataFusionAsyncClient()
 
                 # Initialize request argument(s)
                 instance = data_fusion_v1.Instance()
@@ -732,7 +759,7 @@ class DataFusionAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -817,7 +844,12 @@ class DataFusionAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -841,14 +873,13 @@ class DataFusionAsyncClient:
         r"""Restart a single Data Fusion instance.
         At the end of an operation instance is fully restarted.
 
-
         .. code-block:: python
 
             from google.cloud import data_fusion_v1
 
-            def sample_restart_instance():
+            async def sample_restart_instance():
                 # Create a client
-                client = data_fusion_v1.DataFusionClient()
+                client = data_fusion_v1.DataFusionAsyncClient()
 
                 # Initialize request argument(s)
                 request = data_fusion_v1.RestartInstanceRequest(
@@ -860,7 +891,7 @@ class DataFusionAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -902,7 +933,12 @@ class DataFusionAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
