@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,12 +36,14 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.data_fusion_v1.services.data_fusion import pagers
-from google.cloud.data_fusion_v1.types import datafusion
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DataFusionTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.data_fusion_v1.services.data_fusion import pagers
+from google.cloud.data_fusion_v1.types import datafusion
+
+from .transports.base import DEFAULT_CLIENT_INFO, DataFusionTransport
 from .transports.grpc import DataFusionGrpcTransport
 from .transports.grpc_asyncio import DataFusionGrpcAsyncIOTransport
 
@@ -58,7 +60,10 @@ class DataFusionClientMeta(type):
     _transport_registry["grpc"] = DataFusionGrpcTransport
     _transport_registry["grpc_asyncio"] = DataFusionGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[DataFusionTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[DataFusionTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -167,7 +172,10 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
     @staticmethod
     def crypto_key_path(
-        project: str, location: str, key_ring: str, crypto_key: str,
+        project: str,
+        location: str,
+        key_ring: str,
+        crypto_key: str,
     ) -> str:
         """Returns a fully-qualified crypto_key string."""
         return "projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}".format(
@@ -187,10 +195,16 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def instance_path(project: str, location: str, instance: str,) -> str:
+    def instance_path(
+        project: str,
+        location: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "projects/{project}/locations/{location}/instances/{instance}".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -203,7 +217,9 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -216,9 +232,13 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -227,9 +247,13 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -238,9 +262,13 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -249,10 +277,14 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -424,6 +456,7 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_available_versions(
@@ -438,7 +471,6 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         r"""Lists possible versions for Data Fusion instances in
         the specified project and location.
 
-
         .. code-block:: python
 
             from google.cloud import data_fusion_v1
@@ -519,12 +551,20 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListAvailableVersionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -541,7 +581,6 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         r"""Lists Data Fusion instances in the specified project
         and location.
 
-
         .. code-block:: python
 
             from google.cloud import data_fusion_v1
@@ -600,12 +639,20 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInstancesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -673,7 +720,12 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -692,7 +744,6 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         r"""Creates a new Data Fusion instance in the specified
         project and location.
 
-
         .. code-block:: python
 
             from google.cloud import data_fusion_v1
@@ -792,7 +843,12 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -872,9 +928,6 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -908,7 +961,12 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1039,7 +1097,12 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1063,7 +1126,6 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         r"""Restart a single Data Fusion instance.
         At the end of an operation instance is fully restarted.
 
-
         .. code-block:: python
 
             from google.cloud import data_fusion_v1
@@ -1125,7 +1187,12 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
